"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isDevelopment = isDevelopment;
exports.toArray = toArray;
exports.toError = toError;
exports.validateFields = validateFields;
exports.findRelUiSchema = findRelUiSchema;
exports.findRelSchema = findRelSchema;
exports.findRelForm = findRelForm;
function isDevelopment() {
  return process.env.NODE_ENV !== "production";
}

function toArray(field) {
  if (Array.isArray(field)) {
    return field;
  } else {
    return [field];
  }
}

function toError(message) {
  if (isDevelopment()) {
    throw new ReferenceError(message);
  } else {
    console.error(message);
  }
}

function validateFields(action) {
  var toFields = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function (_ref) {
    var field = _ref.field;
    return field;
  };

  return function (params, schema) {
    var field = toFields(params);
    if (Array.isArray(field)) {
      field.filter(function (f) {
        return schema && schema.properties && schema.properties[f] === undefined;
      }).forEach(function (f) {
        return toError("Field  \"" + f + "\" is missing from schema on \"" + action + "\"");
      });
    } else if (field.indexOf(".") === -1 && schema && schema.properties && schema.properties[field] === undefined) {
      toError("Field  \"" + field + "\" is missing from schema on \"" + action + "\"");
    }
  };
}

function findRelUiSchema(field, uiSchema) {
  var defaultVal = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var separator = field.indexOf(".");
  if (separator === -1) {
    if (!uiSchema[field]) {
      uiSchema[field] = defaultVal;
    }
    return uiSchema[field];
  } else {
    var parentField = field.substr(0, separator);
    if (!uiSchema[parentField]) {
      uiSchema[parentField] = {};
    }
    return findRelUiSchema(field.substr(separator + 1), uiSchema[parentField], defaultVal);
  }
}

function findRelSchema(field, schema) {
  var separator = field.indexOf(".");
  if (separator === -1) {
    return schema;
  } else {
    var parentField = field.substr(0, separator);
    return findRelSchema(field.substr(separator + 1), schema.definitions[parentField]);
  }
}

function findRelForm(field) {
  var formData = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var separator = field.indexOf(".");
  if (separator === -1) {
    return formData;
  } else {
    var parentField = field.substr(0, separator);
    return findRelForm(field.substr(separator + 1), formData[parentField]);
  }
}